@@ -5,6 +5,7 @@ from trainloop_cli.commands.init import init_command as init_cmd
 from trainloop_cli.commands.eval import eval_command as eval_cmd
 from trainloop_cli.commands.studio import studio_command as studio_cmd
 from trainloop_cli.commands.add import add_command
+from trainloop_cli.commands.benchmark import benchmark_command as benchmark_cmd
 
 
 @click.group(
@@ -32,9 +33,14 @@ def studio(config, local):
 
 
 @cli.command("init")
-def init():
+@click.option(
+    "--force",
+    is_flag=True,
+    help="Overwrite an existing 'trainloop' directory if it exists.",
+)
+def init(force: bool):
     """Scaffold data/ and eval/ directories, create sample metrics and suites."""
-    init_cmd()
+    init_cmd(force=force)
 
 
 @cli.command("eval")
@@ -95,6 +101,12 @@ def add(component_type, name, force, version, list_components, registry):
         add_command(component_type, name, force, version, False, registry)
 
 
+@cli.command("benchmark")
+def benchmark():
+    """Compare evaluation results across multiple LLM providers."""
+    benchmark_cmd()
+
+
 def main():
     """Main entry point for the CLI."""
     # Pass control to Click - it will handle the context
